populate_network_graph

Function populate_network_graph 

pub fn populate_network_graph<'a>(
    channels: Vec<SimulatedChannel>,
) -> Result<NetworkGraph<&'a WrappedLog>, LightningError>
Populates a network graph based on the set of simulated channels provided. This function only applies channel announcements, which has the effect of adding the nodes in each channel to the graph, because LDK does not export all of the fields required to apply node announcements. This means that we will not have node-level information (such as features) available in the routing graph.